/*
    +--------------------------------------------------------------------+
    | PECL :: crapi                                                      |
    +--------------------------------------------------------------------+
    | Redistribution and use in source and binary forms, with or without |
    | modification, are permitted provided that the conditions mentioned |
    | in the accompanying LICENSE file are met.                          |
    +--------------------------------------------------------------------+
    | Copyright (c) 2006, Michael Wallner <mike@php.net>                 |
    +--------------------------------------------------------------------+
*/

/* $Id$ */

#ifdef HAVE_CONFIG_H
#	include "config.h"
#endif

#include "php.h"
#include "zend_interfaces.h"
#include "zend_exceptions.h"
#include "ext/standard/info.h"
#include "php_crapi.h"

/* {{{ class entries */
zend_class_entry *php_ce_RepositoryAccessDeniedException;
zend_class_entry *php_ce_RepositoryConstraintViolationException;
zend_class_entry *php_ce_RepositoryCredentials;
zend_class_entry *php_ce_RepositoryEvent;
zend_class_entry *php_ce_RepositoryEventIterator;
zend_class_entry *php_ce_RepositoryEventListener;
zend_class_entry *php_ce_RepositoryEventListenerIterator;
zend_class_entry *php_ce_RepositoryIOException;
zend_class_entry *php_ce_RepositoryIllegalArgumentException;
zend_class_entry *php_ce_RepositoryIllegalStateException;
zend_class_entry *php_ce_RepositoryInvalidItemStateException;
zend_class_entry *php_ce_RepositoryInvalidQueryException;
zend_class_entry *php_ce_RepositoryInvalidSerializedDataException;
zend_class_entry *php_ce_RepositoryItem;
zend_class_entry *php_ce_RepositoryItemDefinition;
zend_class_entry *php_ce_RepositoryItemExistsException;
zend_class_entry *php_ce_RepositoryItemNotFoundException;
zend_class_entry *php_ce_RepositoryItemVisitor;
zend_class_entry *php_ce_RepositoryLock;
zend_class_entry *php_ce_RepositoryLockException;
zend_class_entry *php_ce_RepositoryLoginException;
zend_class_entry *php_ce_RepositoryMergeException;
zend_class_entry *php_ce_RepositoryNamespaceException;
zend_class_entry *php_ce_RepositoryNamespaceRegistry;
zend_class_entry *php_ce_RepositoryNoSuchElementException;
zend_class_entry *php_ce_RepositoryNoSuchNodeTypeException;
zend_class_entry *php_ce_RepositoryNoSuchWorkspaceException;
zend_class_entry *php_ce_RepositoryNode;
zend_class_entry *php_ce_RepositoryNodeDefinition;
zend_class_entry *php_ce_RepositoryNodeIterator;
zend_class_entry *php_ce_RepositoryNodeType;
zend_class_entry *php_ce_RepositoryNodeTypeIterator;
zend_class_entry *php_ce_RepositoryNodeTypeManager;
zend_class_entry *php_ce_RepositoryNumberFormatException;
zend_class_entry *php_ce_RepositoryObservationManager;
zend_class_entry *php_ce_RepositoryOnParentVersionAction;
zend_class_entry *php_ce_RepositoryPathNotFoundException;
zend_class_entry *php_ce_RepositoryProperty;
zend_class_entry *php_ce_RepositoryPropertyDefinition;
zend_class_entry *php_ce_RepositoryPropertyIterator;
zend_class_entry *php_ce_RepositoryPropertyType;
zend_class_entry *php_ce_RepositoryQuery;
zend_class_entry *php_ce_RepositoryQueryManager;
zend_class_entry *php_ce_RepositoryQueryResult;
zend_class_entry *php_ce_RepositoryRangeIterator;
zend_class_entry *php_ce_RepositoryReferentialIntegrityException;
zend_class_entry *php_ce_Repository;
zend_class_entry *php_ce_RepositoryException;
zend_class_entry *php_ce_RepositoryRow;
zend_class_entry *php_ce_RepositoryRowIterator;
zend_class_entry *php_ce_RepositorySAXException;
zend_class_entry *php_ce_RepositorySession;
zend_class_entry *php_ce_RepositorySimpleCredentials;
zend_class_entry *php_ce_RepositoryTraversingItemVisitor;
zend_class_entry *php_ce_RepositoryUnsupportedRepositoryOperationException;
zend_class_entry *php_ce_RepositoryValue;
zend_class_entry *php_ce_RepositoryValueFactory;
zend_class_entry *php_ce_RepositoryValueFormatException;
zend_class_entry *php_ce_RepositoryVersion;
zend_class_entry *php_ce_RepositoryVersionException;
zend_class_entry *php_ce_RepositoryVersionHistory;
zend_class_entry *php_ce_RepositoryVersionIterator;
zend_class_entry *php_ce_RepositoryWorkspace;
zend_class_entry *php_ce_RepositoryAccessDeniedException;
zend_class_entry *php_ce_RepositoryConstraintViolationException;
zend_class_entry *php_ce_RepositoryIOException;
zend_class_entry *php_ce_RepositoryIllegalArgumentException;
zend_class_entry *php_ce_RepositoryIllegalStateException;
zend_class_entry *php_ce_RepositoryInvalidItemStateException;
zend_class_entry *php_ce_RepositoryInvalidQueryException;
zend_class_entry *php_ce_RepositoryInvalidSerializedDataException;
zend_class_entry *php_ce_RepositoryItemExistsException;
zend_class_entry *php_ce_RepositoryItemNotFoundException;
zend_class_entry *php_ce_RepositoryLockException;
zend_class_entry *php_ce_RepositoryLoginException;
zend_class_entry *php_ce_RepositoryMergeException;
zend_class_entry *php_ce_RepositoryNamespaceException;
zend_class_entry *php_ce_RepositoryNoSuchElementException;
zend_class_entry *php_ce_RepositoryNoSuchNodeTypeException;
zend_class_entry *php_ce_RepositoryNoSuchWorkspaceException;
zend_class_entry *php_ce_RepositoryNumberFormatException;
zend_class_entry *php_ce_RepositoryPathNotFoundException;
zend_class_entry *php_ce_RepositoryReferentialIntegrityException;
zend_class_entry *php_ce_RepositoryException;
zend_class_entry *php_ce_RepositorySAXException;
zend_class_entry *php_ce_RepositoryUnsupportedOperationException;
zend_class_entry *php_ce_RepositoryValueFormatException;
zend_class_entry *php_ce_RepositoryVersionException;
/* }}} */

/* {{{ arg info */
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryEvent_getType, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryEvent_getPath, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryEvent_getUserId, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryEventIterator_nextEvent, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryEventListener_onEvent, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, events, RepositoryEventIterator, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryEventListenerIterator_nextEventListener, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_getPath, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_getName, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_getAncestor, 0, 0, 1)
	ZEND_ARG_INFO(0, depth)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_getParent, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_getDepth, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_getSession, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_isNode, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_isNew, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_isModified, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_isSame, 0, 0, 1)
	ZEND_ARG_INFO(0, otherItem)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_accept, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, visitor, RepositoryItemVisitor, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_save, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_refresh, 0, 0, 1)
	ZEND_ARG_INFO(0, keepChanges)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItem_remove, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItemDefinition_getDeclaringNodeType, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItemDefinition_getName, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItemDefinition_isAutoCreate, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItemDefinition_isMandatory, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItemDefinition_getOnParentVersion, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItemDefinition_isProtected, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryItemVisitor_visit, 0, 0, 1)
	ZEND_ARG_INFO(0, entry)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryLock_getLockOwner, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryLock_isDeep, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryLock_getNode, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryLock_getLockToken, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryLock_isLive, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryLock_isSessionScoped, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryLock_refresh, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNamespaceRegistry_registerNamespace, 0, 0, 2)
	ZEND_ARG_INFO(0, prefix)
	ZEND_ARG_INFO(0, uri)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNamespaceRegistry_unregisterNamespace, 0, 0, 1)
	ZEND_ARG_INFO(0, prefix)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNamespaceRegistry_getPrefixes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNamespaceRegistry_getURIs, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNamespaceRegistry_getURI, 0, 0, 1)
	ZEND_ARG_INFO(0, prefix)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNamespaceRegistry_getPrefix, 0, 0, 1)
	ZEND_ARG_INFO(0, uri)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_addNode, 0, 0, 1)
	ZEND_ARG_INFO(0, relPath)
	ZEND_ARG_INFO(0, primaryNodeTypeName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_orderBefore, 0, 0, 2)
	ZEND_ARG_INFO(0, srcChildRelPath)
	ZEND_ARG_INFO(0, destChildRelPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getIndex, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_addExistingNode, 0, 0, 1)
	ZEND_ARG_INFO(0, absPath)
	ZEND_ARG_INFO(0, newName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_setProperty, 0, 0, 2)
	ZEND_ARG_INFO(0, name)
	ZEND_ARG_INFO(0, val)
	ZEND_ARG_INFO(0, type)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getNode, 0, 0, 1)
	ZEND_ARG_INFO(0, relPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getNodes, 0, 0, 0)
	ZEND_ARG_INFO(0, namePattern)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getProperty, 0, 0, 1)
	ZEND_ARG_INFO(0, relPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getProperties, 0, 0, 0)
	ZEND_ARG_INFO(0, namePattern)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getReferences, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_findProperty, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, value, RepositoryValue, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_findProperties, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, value, RepositoryValue, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getPrimaryItem, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getUUID, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_hasNode, 0, 0, 1)
	ZEND_ARG_INFO(0, relPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_hasProperty, 0, 0, 1)
	ZEND_ARG_INFO(0, relPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_hasNodes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_hasProperties, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getPrimaryNodeType, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getMixinNodeTypes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_isNodeType, 0, 0, 1)
	ZEND_ARG_INFO(0, nodeTypeName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_addMixin, 0, 0, 1)
	ZEND_ARG_INFO(0, mixinName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_removeMixin, 0, 0, 1)
	ZEND_ARG_INFO(0, mixinName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_canAddMixin, 0, 0, 1)
	ZEND_ARG_INFO(0, mixinName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getDefinition, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_checkin, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_checkout, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_update, 0, 0, 2)
	ZEND_ARG_INFO(0, srcWorkspaceName)
	ZEND_ARG_INFO(0, shallow)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_merge, 0, 0, 2)
	ZEND_ARG_INFO(0, srcWorkspace)
	ZEND_ARG_INFO(0, shallow)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_isCheckedOut, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_restore, 0, 0, 1)
	ZEND_ARG_INFO(0, in)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_restoreByLabel, 0, 0, 1)
	ZEND_ARG_INFO(0, versionLabel)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getVersionHistory, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getBaseVersion, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_doneMerge, 0, 0, 1)
	ZEND_ARG_INFO(0, version)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_cancelMerge, 0, 0, 1)
	ZEND_ARG_INFO(0, version)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getCorrespondingNodePath, 0, 0, 1)
	ZEND_ARG_INFO(0, workspaceName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_lock, 0, 0, 2)
	ZEND_ARG_INFO(0, isDeep)
	ZEND_ARG_INFO(0, isSessionScoped)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_getLock, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_unlock, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_holdsLock, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNode_isLocked, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeDefinition_getRequiredPrimaryTypes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeDefinition_getDefaultPrimaryType, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeDefinition_allowSameNameSibs, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeIterator_nextNode, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_getName, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_isMixin, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_hasOrderableChildNodes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_getPrimaryItemName, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_getSupertypes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_getDeclaredSupertypes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_isNodeType, 0, 0, 1)
	ZEND_ARG_INFO(0, nodeTypeName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_getPropertyDefinitions, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_getDeclaredPropertyDefinitions, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_getChildNodeDefinitions, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_getDeclaredChildNodeDefinitions, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_canSetProperty, 0, 0, 2)
	ZEND_ARG_INFO(0, propertyName)
	ZEND_ARG_INFO(0, value)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_canAddChildNode, 0, 0, 1)
	ZEND_ARG_INFO(0, childNodeName)
	ZEND_ARG_INFO(0, nodeTypeName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeType_canRemoveItem, 0, 0, 1)
	ZEND_ARG_INFO(0, itemName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeTypeIterator_nextNodeType, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeTypeManager_getNodeType, 0, 0, 1)
	ZEND_ARG_INFO(0, nodeTypeName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeTypeManager_getAllNodeTypes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeTypeManager_getPrimaryNodeTypes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryNodeTypeManager_getMixinNodeTypes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryObservationManager_addEventListener, 0, 0, 7)
	ZEND_ARG_OBJ_INFO(0, listener, RepositoryEventListener, 0)
	ZEND_ARG_INFO(0, eventTypes)
	ZEND_ARG_INFO(0, absPath)
	ZEND_ARG_INFO(0, isDeep)
	ZEND_ARG_INFO(0, uuid)
	ZEND_ARG_INFO(0, nodeTypeName)
	ZEND_ARG_INFO(0, noLocal)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryObservationManager_removeEventListener, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, listener, RepositoryEventListener, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryObservationManager_getRegisteredEventListeners, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryOnParentVersionAction___construct, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryOnParentVersionAction_nameFromValue, 0, 0, 1)
	ZEND_ARG_INFO(0, action)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryOnParentVersionAction_valueFromName, 0, 0, 1)
	ZEND_ARG_INFO(0, name)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_setValue, 0, 0, 1)
	ZEND_ARG_INFO(0, value)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getValue, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getValues, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getString, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getStream, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getLong, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getDouble, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getDate, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getBoolean, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getNode, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getLength, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getLengths, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getDefinition, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryProperty_getType, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryPropertyDefinition_getRequiredType, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryPropertyDefinition_getValueConstraints, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryPropertyDefinition_getDefaultValues, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryPropertyDefinition_isMultiple, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryPropertyIterator_nextProperty, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryPropertyType_nameFromValue, 0, 0, 1)
	ZEND_ARG_INFO(0, type)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryPropertyType_valueFromName, 0, 0, 1)
	ZEND_ARG_INFO(0, name)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQuery_execute, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQuery_getStatement, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQuery_getLanguage, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQuery_getStoredQueryPath, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQuery_storeAsNode, 0, 0, 1)
	ZEND_ARG_INFO(0, absPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQueryManager_createQuery, 0, 0, 2)
	ZEND_ARG_INFO(0, statement)
	ZEND_ARG_INFO(0, language)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQueryManager_getQuery, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, node, RepositoryNode, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQueryManager_getSupportedQueryLanguages, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQueryResult_getColumnNames, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQueryResult_getRows, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryQueryResult_getNodes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryRangeIterator_skip, 0, 0, 1)
	ZEND_ARG_INFO(0, skipNum)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryRangeIterator_getSize, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryRangeIterator_getPos, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_Repository_getDescriptorKeys, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_Repository_getDescriptor, 0, 0, 1)
	ZEND_ARG_INFO(0, key)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_Repository_login, 0, 0, 0)
	ZEND_ARG_INFO(0, credentials)
	ZEND_ARG_INFO(0, workspaceName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryRow_getValues, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryRow_getValue, 0, 0, 1)
	ZEND_ARG_INFO(0, propertyName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryRowIterator_nextRow, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getRepository, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getUserID, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getAttribute, 0, 0, 1)
	ZEND_ARG_INFO(0, name)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getAttributeNames, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_isLive, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getValueFactory, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getWorkspace, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_impersonate, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, credentials, RepositoryCredentials, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getRootNode, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getNodeByUUID, 0, 0, 1)
	ZEND_ARG_INFO(0, uuid)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getItem, 0, 0, 1)
	ZEND_ARG_INFO(0, absPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_itemExists, 0, 0, 1)
	ZEND_ARG_INFO(0, absPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_move, 0, 0, 2)
	ZEND_ARG_INFO(0, srcAbsPath)
	ZEND_ARG_INFO(0, destAbsPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_save, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_refresh, 0, 0, 1)
	ZEND_ARG_INFO(0, keepChanges)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_hasPendingChanges, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_checkPermission, 0, 0, 2)
	ZEND_ARG_INFO(0, absPath)
	ZEND_ARG_INFO(0, actions)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getImportContentHandler, 0, 0, 2)
	ZEND_ARG_INFO(0, parentAbsPath)
	ZEND_ARG_INFO(0, mode)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_importXML, 0, 0, 3)
	ZEND_ARG_INFO(0, parentAbsPath)
	ZEND_ARG_INFO(0, in)
	ZEND_ARG_INFO(0, mode)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_exportSystemView, 0, 0, 4)
	ZEND_ARG_INFO(0, absPath)
	ZEND_ARG_INFO(0, out)
	ZEND_ARG_INFO(0, skipBinary)
	ZEND_ARG_INFO(0, noRecurse)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_exportDocumentView, 0, 0, 4)
	ZEND_ARG_INFO(0, absPath)
	ZEND_ARG_INFO(0, out)
	ZEND_ARG_INFO(0, skipBinary)
	ZEND_ARG_INFO(0, noRecurse)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_setNamespacePrefix, 0, 0, 2)
	ZEND_ARG_INFO(0, prefix)
	ZEND_ARG_INFO(0, uri)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getNamespacePrefixes, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getNamespaceURI, 0, 0, 1)
	ZEND_ARG_INFO(0, prefix)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getNamespacePrefix, 0, 0, 1)
	ZEND_ARG_INFO(0, uri)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_logout, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_addLockToken, 0, 0, 1)
	ZEND_ARG_INFO(0, lt)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_getLockTokens, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySession_removeLockToken, 0, 0, 1)
	ZEND_ARG_INFO(0, lt)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySimpleCredentials___construct, 0, 0, 2)
	ZEND_ARG_INFO(0, userId)
	ZEND_ARG_INFO(0, password)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySimpleCredentials_getPassword, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySimpleCredentials_getUserId, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySimpleCredentials_setAttribute, 0, 0, 0)
	ZEND_ARG_INFO(0, name)
	ZEND_ARG_INFO(0, value)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySimpleCredentials_getAttribute, 0, 0, 1)
	ZEND_ARG_INFO(0, name)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySimpleCredentials_removeAttribute, 0, 0, 1)
	ZEND_ARG_INFO(0, name)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositorySimpleCredentials_getAttributeNames, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryTraversingItemVisitor___construct, 0, 0, 0)
	ZEND_ARG_INFO(0, breadthFirst)
	ZEND_ARG_INFO(0, maxLevel)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryTraversingItemVisitor_entering, 0, 0, 2)
	ZEND_ARG_INFO(0, entry)
	ZEND_ARG_INFO(0, level)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryTraversingItemVisitor_leaving, 0, 0, 2)
	ZEND_ARG_INFO(0, entry)
	ZEND_ARG_INFO(0, level)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryTraversingItemVisitor_visit, 0, 0, 1)
	ZEND_ARG_INFO(0, entry)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryValue_getString, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryValue_getStream, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryValue_getLong, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryValue_getDouble, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryValue_getDate, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryValue_getBoolean, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryValue_getType, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryValueFactory_createValue, 0, 0, 1)
	ZEND_ARG_INFO(0, value)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersion_getContainingHistory, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersion_getCreated, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersion_getSuccessors, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersion_getPredecessors, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_getVersionableUUID, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_getRootVersion, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_getAllVersions, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_getVersion, 0, 0, 1)
	ZEND_ARG_INFO(0, versionName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_getVersionByLabel, 0, 0, 1)
	ZEND_ARG_INFO(0, label)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_addVersionLabel, 0, 0, 3)
	ZEND_ARG_INFO(0, versionName)
	ZEND_ARG_INFO(0, label)
	ZEND_ARG_INFO(0, moveLabel)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_removeVersionLabel, 0, 0, 1)
	ZEND_ARG_INFO(0, label)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_hasVersionLabel, 0, 0, 2)
	ZEND_ARG_OBJ_INFO(0, version, RepositoryVersion, 0)
	ZEND_ARG_INFO(0, label)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_getVersionLabels, 0, 0, 1)
	ZEND_ARG_OBJ_INFO(0, version, RepositoryVersion, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionHistory_removeVersion, 0, 0, 1)
	ZEND_ARG_INFO(0, versionName)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryVersionIterator_nextVersion, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_getSession, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_getName, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_copy, 0, 0, 3)
	ZEND_ARG_INFO(0, srcWorkspace)
	ZEND_ARG_INFO(0, srcAbsPath)
	ZEND_ARG_INFO(0, destAbsPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_clone_, 0, 0, 2)
	ZEND_ARG_INFO(0, srcAbsPath)
	ZEND_ARG_INFO(0, destAbsPath)
	ZEND_ARG_INFO(0, srcWorkspace)
	ZEND_ARG_INFO(0, removeExisting)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_move, 0, 0, 2)
	ZEND_ARG_INFO(0, srcAbsPath)
	ZEND_ARG_INFO(0, destAbsPath)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_restore, 0, 0, 2)
	ZEND_ARG_INFO(0, versions)
	ZEND_ARG_INFO(0, removeExisting)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_getQueryManager, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_getNamespaceRegistry, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_getNodeTypeManager, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_getObservationManager, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_getAccessibleWorkspaceNames, 0, 0, 0)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_getImportContentHandler, 0, 0, 2)
	ZEND_ARG_INFO(0, parentAbsPath)
	ZEND_ARG_INFO(0, uuidBehavior)
ZEND_END_ARG_INFO();
ZEND_BEGIN_ARG_INFO_EX(php_ai_RepositoryWorkspace_importXML, 0, 0, 3)
	ZEND_ARG_INFO(0, parentAbsPath)
	ZEND_ARG_INFO(0, in)
	ZEND_ARG_INFO(0, uuidBehavior)
ZEND_END_ARG_INFO();
/* }}} */

/* {{{ method entries */
zend_function_entry php_fe_RepositoryEvent[] = {
	PHP_ABSTRACT_ME(RepositoryEvent, getType, php_ai_RepositoryEvent_getType)
	PHP_ABSTRACT_ME(RepositoryEvent, getPath, php_ai_RepositoryEvent_getPath)
	PHP_ABSTRACT_ME(RepositoryEvent, getUserId, php_ai_RepositoryEvent_getUserId)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryEventIterator[] = {
	PHP_ABSTRACT_ME(RepositoryEventIterator, nextEvent, php_ai_RepositoryEventIterator_nextEvent)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryEventListener[] = {
	PHP_ABSTRACT_ME(RepositoryEventListener, onEvent, php_ai_RepositoryEventListener_onEvent)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryEventListenerIterator[] = {
	PHP_ABSTRACT_ME(RepositoryEventListenerIterator, nextEventListener, php_ai_RepositoryEventListenerIterator_nextEventListener)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryItem[] = {
	PHP_ABSTRACT_ME(RepositoryItem, getPath, php_ai_RepositoryItem_getPath)
	PHP_ABSTRACT_ME(RepositoryItem, getName, php_ai_RepositoryItem_getName)
	PHP_ABSTRACT_ME(RepositoryItem, getAncestor, php_ai_RepositoryItem_getAncestor)
	PHP_ABSTRACT_ME(RepositoryItem, getParent, php_ai_RepositoryItem_getParent)
	PHP_ABSTRACT_ME(RepositoryItem, getDepth, php_ai_RepositoryItem_getDepth)
	PHP_ABSTRACT_ME(RepositoryItem, getSession, php_ai_RepositoryItem_getSession)
	PHP_ABSTRACT_ME(RepositoryItem, isNode, php_ai_RepositoryItem_isNode)
	PHP_ABSTRACT_ME(RepositoryItem, isNew, php_ai_RepositoryItem_isNew)
	PHP_ABSTRACT_ME(RepositoryItem, isModified, php_ai_RepositoryItem_isModified)
	PHP_ABSTRACT_ME(RepositoryItem, isSame, php_ai_RepositoryItem_isSame)
	PHP_ABSTRACT_ME(RepositoryItem, accept, php_ai_RepositoryItem_accept)
	PHP_ABSTRACT_ME(RepositoryItem, save, php_ai_RepositoryItem_save)
	PHP_ABSTRACT_ME(RepositoryItem, refresh, php_ai_RepositoryItem_refresh)
	PHP_ABSTRACT_ME(RepositoryItem, remove, php_ai_RepositoryItem_remove)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryItemDefinition[] = {
	PHP_ABSTRACT_ME(RepositoryItemDefinition, getDeclaringNodeType, php_ai_RepositoryItemDefinition_getDeclaringNodeType)
	PHP_ABSTRACT_ME(RepositoryItemDefinition, getName, php_ai_RepositoryItemDefinition_getName)
	PHP_ABSTRACT_ME(RepositoryItemDefinition, isAutoCreate, php_ai_RepositoryItemDefinition_isAutoCreate)
	PHP_ABSTRACT_ME(RepositoryItemDefinition, isMandatory, php_ai_RepositoryItemDefinition_isMandatory)
	PHP_ABSTRACT_ME(RepositoryItemDefinition, getOnParentVersion, php_ai_RepositoryItemDefinition_getOnParentVersion)
	PHP_ABSTRACT_ME(RepositoryItemDefinition, isProtected, php_ai_RepositoryItemDefinition_isProtected)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryItemVisitor[] = {
	PHP_ABSTRACT_ME(RepositoryItemVisitor, visit, php_ai_RepositoryItemVisitor_visit)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryLock[] = {
	PHP_ABSTRACT_ME(RepositoryLock, getLockOwner, php_ai_RepositoryLock_getLockOwner)
	PHP_ABSTRACT_ME(RepositoryLock, isDeep, php_ai_RepositoryLock_isDeep)
	PHP_ABSTRACT_ME(RepositoryLock, getNode, php_ai_RepositoryLock_getNode)
	PHP_ABSTRACT_ME(RepositoryLock, getLockToken, php_ai_RepositoryLock_getLockToken)
	PHP_ABSTRACT_ME(RepositoryLock, isLive, php_ai_RepositoryLock_isLive)
	PHP_ABSTRACT_ME(RepositoryLock, isSessionScoped, php_ai_RepositoryLock_isSessionScoped)
	PHP_ABSTRACT_ME(RepositoryLock, refresh, php_ai_RepositoryLock_refresh)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryNamespaceRegistry[] = {
	PHP_ABSTRACT_ME(RepositoryNamespaceRegistry, registerNamespace, php_ai_RepositoryNamespaceRegistry_registerNamespace)
	PHP_ABSTRACT_ME(RepositoryNamespaceRegistry, unregisterNamespace, php_ai_RepositoryNamespaceRegistry_unregisterNamespace)
	PHP_ABSTRACT_ME(RepositoryNamespaceRegistry, getPrefixes, php_ai_RepositoryNamespaceRegistry_getPrefixes)
	PHP_ABSTRACT_ME(RepositoryNamespaceRegistry, getURIs, php_ai_RepositoryNamespaceRegistry_getURIs)
	PHP_ABSTRACT_ME(RepositoryNamespaceRegistry, getURI, php_ai_RepositoryNamespaceRegistry_getURI)
	PHP_ABSTRACT_ME(RepositoryNamespaceRegistry, getPrefix, php_ai_RepositoryNamespaceRegistry_getPrefix)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryNode[] = {
	PHP_ABSTRACT_ME(RepositoryNode, addNode, php_ai_RepositoryNode_addNode)
	PHP_ABSTRACT_ME(RepositoryNode, orderBefore, php_ai_RepositoryNode_orderBefore)
	PHP_ABSTRACT_ME(RepositoryNode, getIndex, php_ai_RepositoryNode_getIndex)
	PHP_ABSTRACT_ME(RepositoryNode, addExistingNode, php_ai_RepositoryNode_addExistingNode)
	PHP_ABSTRACT_ME(RepositoryNode, setProperty, php_ai_RepositoryNode_setProperty)
	PHP_ABSTRACT_ME(RepositoryNode, getNode, php_ai_RepositoryNode_getNode)
	PHP_ABSTRACT_ME(RepositoryNode, getNodes, php_ai_RepositoryNode_getNodes)
	PHP_ABSTRACT_ME(RepositoryNode, getProperty, php_ai_RepositoryNode_getProperty)
	PHP_ABSTRACT_ME(RepositoryNode, getProperties, php_ai_RepositoryNode_getProperties)
	PHP_ABSTRACT_ME(RepositoryNode, getReferences, php_ai_RepositoryNode_getReferences)
	PHP_ABSTRACT_ME(RepositoryNode, findProperty, php_ai_RepositoryNode_findProperty)
	PHP_ABSTRACT_ME(RepositoryNode, findProperties, php_ai_RepositoryNode_findProperties)
	PHP_ABSTRACT_ME(RepositoryNode, getPrimaryItem, php_ai_RepositoryNode_getPrimaryItem)
	PHP_ABSTRACT_ME(RepositoryNode, getUUID, php_ai_RepositoryNode_getUUID)
	PHP_ABSTRACT_ME(RepositoryNode, hasNode, php_ai_RepositoryNode_hasNode)
	PHP_ABSTRACT_ME(RepositoryNode, hasProperty, php_ai_RepositoryNode_hasProperty)
	PHP_ABSTRACT_ME(RepositoryNode, hasNodes, php_ai_RepositoryNode_hasNodes)
	PHP_ABSTRACT_ME(RepositoryNode, hasProperties, php_ai_RepositoryNode_hasProperties)
	PHP_ABSTRACT_ME(RepositoryNode, getPrimaryNodeType, php_ai_RepositoryNode_getPrimaryNodeType)
	PHP_ABSTRACT_ME(RepositoryNode, getMixinNodeTypes, php_ai_RepositoryNode_getMixinNodeTypes)
	PHP_ABSTRACT_ME(RepositoryNode, isNodeType, php_ai_RepositoryNode_isNodeType)
	PHP_ABSTRACT_ME(RepositoryNode, addMixin, php_ai_RepositoryNode_addMixin)
	PHP_ABSTRACT_ME(RepositoryNode, removeMixin, php_ai_RepositoryNode_removeMixin)
	PHP_ABSTRACT_ME(RepositoryNode, canAddMixin, php_ai_RepositoryNode_canAddMixin)
	PHP_ABSTRACT_ME(RepositoryNode, getDefinition, php_ai_RepositoryNode_getDefinition)
	PHP_ABSTRACT_ME(RepositoryNode, checkin, php_ai_RepositoryNode_checkin)
	PHP_ABSTRACT_ME(RepositoryNode, checkout, php_ai_RepositoryNode_checkout)
	PHP_ABSTRACT_ME(RepositoryNode, update, php_ai_RepositoryNode_update)
	PHP_ABSTRACT_ME(RepositoryNode, merge, php_ai_RepositoryNode_merge)
	PHP_ABSTRACT_ME(RepositoryNode, isCheckedOut, php_ai_RepositoryNode_isCheckedOut)
	PHP_ABSTRACT_ME(RepositoryNode, restore, php_ai_RepositoryNode_restore)
	PHP_ABSTRACT_ME(RepositoryNode, restoreByLabel, php_ai_RepositoryNode_restoreByLabel)
	PHP_ABSTRACT_ME(RepositoryNode, getVersionHistory, php_ai_RepositoryNode_getVersionHistory)
	PHP_ABSTRACT_ME(RepositoryNode, getBaseVersion, php_ai_RepositoryNode_getBaseVersion)
	PHP_ABSTRACT_ME(RepositoryNode, doneMerge, php_ai_RepositoryNode_doneMerge)
	PHP_ABSTRACT_ME(RepositoryNode, cancelMerge, php_ai_RepositoryNode_cancelMerge)
	PHP_ABSTRACT_ME(RepositoryNode, getCorrespondingNodePath, php_ai_RepositoryNode_getCorrespondingNodePath)
	PHP_ABSTRACT_ME(RepositoryNode, lock, php_ai_RepositoryNode_lock)
	PHP_ABSTRACT_ME(RepositoryNode, getLock, php_ai_RepositoryNode_getLock)
	PHP_ABSTRACT_ME(RepositoryNode, unlock, php_ai_RepositoryNode_unlock)
	PHP_ABSTRACT_ME(RepositoryNode, holdsLock, php_ai_RepositoryNode_holdsLock)
	PHP_ABSTRACT_ME(RepositoryNode, isLocked, php_ai_RepositoryNode_isLocked)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryNodeDefinition[] = {
	PHP_ABSTRACT_ME(RepositoryNodeDefinition, getRequiredPrimaryTypes, php_ai_RepositoryNodeDefinition_getRequiredPrimaryTypes)
	PHP_ABSTRACT_ME(RepositoryNodeDefinition, getDefaultPrimaryType, php_ai_RepositoryNodeDefinition_getDefaultPrimaryType)
	PHP_ABSTRACT_ME(RepositoryNodeDefinition, allowSameNameSibs, php_ai_RepositoryNodeDefinition_allowSameNameSibs)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryNodeIterator[] = {
	PHP_ABSTRACT_ME(RepositoryNodeIterator, nextNode, php_ai_RepositoryNodeIterator_nextNode)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryNodeType[] = {
	PHP_ABSTRACT_ME(RepositoryNodeType, getName, php_ai_RepositoryNodeType_getName)
	PHP_ABSTRACT_ME(RepositoryNodeType, isMixin, php_ai_RepositoryNodeType_isMixin)
	PHP_ABSTRACT_ME(RepositoryNodeType, hasOrderableChildNodes, php_ai_RepositoryNodeType_hasOrderableChildNodes)
	PHP_ABSTRACT_ME(RepositoryNodeType, getPrimaryItemName, php_ai_RepositoryNodeType_getPrimaryItemName)
	PHP_ABSTRACT_ME(RepositoryNodeType, getSupertypes, php_ai_RepositoryNodeType_getSupertypes)
	PHP_ABSTRACT_ME(RepositoryNodeType, getDeclaredSupertypes, php_ai_RepositoryNodeType_getDeclaredSupertypes)
	PHP_ABSTRACT_ME(RepositoryNodeType, isNodeType, php_ai_RepositoryNodeType_isNodeType)
	PHP_ABSTRACT_ME(RepositoryNodeType, getPropertyDefinitions, php_ai_RepositoryNodeType_getPropertyDefinitions)
	PHP_ABSTRACT_ME(RepositoryNodeType, getDeclaredPropertyDefinitions, php_ai_RepositoryNodeType_getDeclaredPropertyDefinitions)
	PHP_ABSTRACT_ME(RepositoryNodeType, getChildNodeDefinitions, php_ai_RepositoryNodeType_getChildNodeDefinitions)
	PHP_ABSTRACT_ME(RepositoryNodeType, getDeclaredChildNodeDefinitions, php_ai_RepositoryNodeType_getDeclaredChildNodeDefinitions)
	PHP_ABSTRACT_ME(RepositoryNodeType, canSetProperty, php_ai_RepositoryNodeType_canSetProperty)
	PHP_ABSTRACT_ME(RepositoryNodeType, canAddChildNode, php_ai_RepositoryNodeType_canAddChildNode)
	PHP_ABSTRACT_ME(RepositoryNodeType, canRemoveItem, php_ai_RepositoryNodeType_canRemoveItem)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryNodeTypeIterator[] = {
	PHP_ABSTRACT_ME(RepositoryNodeTypeIterator, nextNodeType, php_ai_RepositoryNodeTypeIterator_nextNodeType)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryNodeTypeManager[] = {
	PHP_ABSTRACT_ME(RepositoryNodeTypeManager, getNodeType, php_ai_RepositoryNodeTypeManager_getNodeType)
	PHP_ABSTRACT_ME(RepositoryNodeTypeManager, getAllNodeTypes, php_ai_RepositoryNodeTypeManager_getAllNodeTypes)
	PHP_ABSTRACT_ME(RepositoryNodeTypeManager, getPrimaryNodeTypes, php_ai_RepositoryNodeTypeManager_getPrimaryNodeTypes)
	PHP_ABSTRACT_ME(RepositoryNodeTypeManager, getMixinNodeTypes, php_ai_RepositoryNodeTypeManager_getMixinNodeTypes)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryObservationManager[] = {
	PHP_ABSTRACT_ME(RepositoryObservationManager, addEventListener, php_ai_RepositoryObservationManager_addEventListener)
	PHP_ABSTRACT_ME(RepositoryObservationManager, removeEventListener, php_ai_RepositoryObservationManager_removeEventListener)
	PHP_ABSTRACT_ME(RepositoryObservationManager, getRegisteredEventListeners, php_ai_RepositoryObservationManager_getRegisteredEventListeners)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryOnParentVersionAction[] = {
	PHP_ME(RepositoryOnParentVersionAction, __construct, php_ai_RepositoryOnParentVersionAction___construct, ZEND_ACC_PRIVATE|ZEND_ACC_CTOR)
	PHP_ME(RepositoryOnParentVersionAction, nameFromValue, php_ai_RepositoryOnParentVersionAction_nameFromValue, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
	PHP_ME(RepositoryOnParentVersionAction, valueFromName, php_ai_RepositoryOnParentVersionAction_valueFromName, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryProperty[] = {
	PHP_ABSTRACT_ME(RepositoryProperty, setValue, php_ai_RepositoryProperty_setValue)
	PHP_ABSTRACT_ME(RepositoryProperty, getValue, php_ai_RepositoryProperty_getValue)
	PHP_ABSTRACT_ME(RepositoryProperty, getValues, php_ai_RepositoryProperty_getValues)
	PHP_ABSTRACT_ME(RepositoryProperty, getString, php_ai_RepositoryProperty_getString)
	PHP_ABSTRACT_ME(RepositoryProperty, getStream, php_ai_RepositoryProperty_getStream)
	PHP_ABSTRACT_ME(RepositoryProperty, getLong, php_ai_RepositoryProperty_getLong)
	PHP_ABSTRACT_ME(RepositoryProperty, getDouble, php_ai_RepositoryProperty_getDouble)
	PHP_ABSTRACT_ME(RepositoryProperty, getDate, php_ai_RepositoryProperty_getDate)
	PHP_ABSTRACT_ME(RepositoryProperty, getBoolean, php_ai_RepositoryProperty_getBoolean)
	PHP_ABSTRACT_ME(RepositoryProperty, getNode, php_ai_RepositoryProperty_getNode)
	PHP_ABSTRACT_ME(RepositoryProperty, getLength, php_ai_RepositoryProperty_getLength)
	PHP_ABSTRACT_ME(RepositoryProperty, getLengths, php_ai_RepositoryProperty_getLengths)
	PHP_ABSTRACT_ME(RepositoryProperty, getDefinition, php_ai_RepositoryProperty_getDefinition)
	PHP_ABSTRACT_ME(RepositoryProperty, getType, php_ai_RepositoryProperty_getType)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryPropertyDefinition[] = {
	PHP_ABSTRACT_ME(RepositoryPropertyDefinition, getRequiredType, php_ai_RepositoryPropertyDefinition_getRequiredType)
	PHP_ABSTRACT_ME(RepositoryPropertyDefinition, getValueConstraints, php_ai_RepositoryPropertyDefinition_getValueConstraints)
	PHP_ABSTRACT_ME(RepositoryPropertyDefinition, getDefaultValues, php_ai_RepositoryPropertyDefinition_getDefaultValues)
	PHP_ABSTRACT_ME(RepositoryPropertyDefinition, isMultiple, php_ai_RepositoryPropertyDefinition_isMultiple)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryPropertyIterator[] = {
	PHP_ABSTRACT_ME(RepositoryPropertyIterator, nextProperty, php_ai_RepositoryPropertyIterator_nextProperty)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryPropertyType[] = {
	PHP_ME(RepositoryPropertyType, nameFromValue, php_ai_RepositoryPropertyType_nameFromValue, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
	PHP_ME(RepositoryPropertyType, valueFromName, php_ai_RepositoryPropertyType_valueFromName, ZEND_ACC_PUBLIC|ZEND_ACC_STATIC)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryQuery[] = {
	PHP_ABSTRACT_ME(RepositoryQuery, execute, php_ai_RepositoryQuery_execute)
	PHP_ABSTRACT_ME(RepositoryQuery, getStatement, php_ai_RepositoryQuery_getStatement)
	PHP_ABSTRACT_ME(RepositoryQuery, getLanguage, php_ai_RepositoryQuery_getLanguage)
	PHP_ABSTRACT_ME(RepositoryQuery, getStoredQueryPath, php_ai_RepositoryQuery_getStoredQueryPath)
	PHP_ABSTRACT_ME(RepositoryQuery, storeAsNode, php_ai_RepositoryQuery_storeAsNode)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryQueryManager[] = {
	PHP_ABSTRACT_ME(RepositoryQueryManager, createQuery, php_ai_RepositoryQueryManager_createQuery)
	PHP_ABSTRACT_ME(RepositoryQueryManager, getQuery, php_ai_RepositoryQueryManager_getQuery)
	PHP_ABSTRACT_ME(RepositoryQueryManager, getSupportedQueryLanguages, php_ai_RepositoryQueryManager_getSupportedQueryLanguages)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryQueryResult[] = {
	PHP_ABSTRACT_ME(RepositoryQueryResult, getColumnNames, php_ai_RepositoryQueryResult_getColumnNames)
	PHP_ABSTRACT_ME(RepositoryQueryResult, getRows, php_ai_RepositoryQueryResult_getRows)
	PHP_ABSTRACT_ME(RepositoryQueryResult, getNodes, php_ai_RepositoryQueryResult_getNodes)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryRangeIterator[] = {
	PHP_ABSTRACT_ME(RepositoryRangeIterator, skip, php_ai_RepositoryRangeIterator_skip)
	PHP_ABSTRACT_ME(RepositoryRangeIterator, getSize, php_ai_RepositoryRangeIterator_getSize)
	PHP_ABSTRACT_ME(RepositoryRangeIterator, getPos, php_ai_RepositoryRangeIterator_getPos)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_Repository[] = {
	PHP_ABSTRACT_ME(Repository, getDescriptorKeys, php_ai_Repository_getDescriptorKeys)
	PHP_ABSTRACT_ME(Repository, getDescriptor, php_ai_Repository_getDescriptor)
	PHP_ABSTRACT_ME(Repository, login, php_ai_Repository_login)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryRow[] = {
	PHP_ABSTRACT_ME(RepositoryRow, getValues, php_ai_RepositoryRow_getValues)
	PHP_ABSTRACT_ME(RepositoryRow, getValue, php_ai_RepositoryRow_getValue)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryRowIterator[] = {
	PHP_ABSTRACT_ME(RepositoryRowIterator, nextRow, php_ai_RepositoryRowIterator_nextRow)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositorySession[] = {
	PHP_ABSTRACT_ME(RepositorySession, getRepository, php_ai_RepositorySession_getRepository)
	PHP_ABSTRACT_ME(RepositorySession, getUserID, php_ai_RepositorySession_getUserID)
	PHP_ABSTRACT_ME(RepositorySession, getAttribute, php_ai_RepositorySession_getAttribute)
	PHP_ABSTRACT_ME(RepositorySession, getAttributeNames, php_ai_RepositorySession_getAttributeNames)
	PHP_ABSTRACT_ME(RepositorySession, isLive, php_ai_RepositorySession_isLive)
	PHP_ABSTRACT_ME(RepositorySession, getValueFactory, php_ai_RepositorySession_getValueFactory)
	PHP_ABSTRACT_ME(RepositorySession, getWorkspace, php_ai_RepositorySession_getWorkspace)
	PHP_ABSTRACT_ME(RepositorySession, impersonate, php_ai_RepositorySession_impersonate)
	PHP_ABSTRACT_ME(RepositorySession, getRootNode, php_ai_RepositorySession_getRootNode)
	PHP_ABSTRACT_ME(RepositorySession, getNodeByUUID, php_ai_RepositorySession_getNodeByUUID)
	PHP_ABSTRACT_ME(RepositorySession, getItem, php_ai_RepositorySession_getItem)
	PHP_ABSTRACT_ME(RepositorySession, itemExists, php_ai_RepositorySession_itemExists)
	PHP_ABSTRACT_ME(RepositorySession, move, php_ai_RepositorySession_move)
	PHP_ABSTRACT_ME(RepositorySession, save, php_ai_RepositorySession_save)
	PHP_ABSTRACT_ME(RepositorySession, refresh, php_ai_RepositorySession_refresh)
	PHP_ABSTRACT_ME(RepositorySession, hasPendingChanges, php_ai_RepositorySession_hasPendingChanges)
	PHP_ABSTRACT_ME(RepositorySession, checkPermission, php_ai_RepositorySession_checkPermission)
	PHP_ABSTRACT_ME(RepositorySession, getImportContentHandler, php_ai_RepositorySession_getImportContentHandler)
	PHP_ABSTRACT_ME(RepositorySession, importXML, php_ai_RepositorySession_importXML)
	PHP_ABSTRACT_ME(RepositorySession, exportSystemView, php_ai_RepositorySession_exportSystemView)
	PHP_ABSTRACT_ME(RepositorySession, exportDocumentView, php_ai_RepositorySession_exportDocumentView)
	PHP_ABSTRACT_ME(RepositorySession, setNamespacePrefix, php_ai_RepositorySession_setNamespacePrefix)
	PHP_ABSTRACT_ME(RepositorySession, getNamespacePrefixes, php_ai_RepositorySession_getNamespacePrefixes)
	PHP_ABSTRACT_ME(RepositorySession, getNamespaceURI, php_ai_RepositorySession_getNamespaceURI)
	PHP_ABSTRACT_ME(RepositorySession, getNamespacePrefix, php_ai_RepositorySession_getNamespacePrefix)
	PHP_ABSTRACT_ME(RepositorySession, logout, php_ai_RepositorySession_logout)
	PHP_ABSTRACT_ME(RepositorySession, addLockToken, php_ai_RepositorySession_addLockToken)
	PHP_ABSTRACT_ME(RepositorySession, getLockTokens, php_ai_RepositorySession_getLockTokens)
	PHP_ABSTRACT_ME(RepositorySession, removeLockToken, php_ai_RepositorySession_removeLockToken)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositorySimpleCredentials[] = {
	PHP_ME(RepositorySimpleCredentials, __construct, php_ai_RepositorySimpleCredentials___construct, ZEND_ACC_PUBLIC|ZEND_ACC_CTOR)
	PHP_ME(RepositorySimpleCredentials, getPassword, php_ai_RepositorySimpleCredentials_getPassword, ZEND_ACC_PUBLIC)
	PHP_ME(RepositorySimpleCredentials, getUserId, php_ai_RepositorySimpleCredentials_getUserId, ZEND_ACC_PUBLIC)
	PHP_ME(RepositorySimpleCredentials, setAttribute, php_ai_RepositorySimpleCredentials_setAttribute, ZEND_ACC_PUBLIC)
	PHP_ME(RepositorySimpleCredentials, getAttribute, php_ai_RepositorySimpleCredentials_getAttribute, ZEND_ACC_PUBLIC)
	PHP_ME(RepositorySimpleCredentials, removeAttribute, php_ai_RepositorySimpleCredentials_removeAttribute, ZEND_ACC_PUBLIC)
	PHP_ME(RepositorySimpleCredentials, getAttributeNames, php_ai_RepositorySimpleCredentials_getAttributeNames, ZEND_ACC_PUBLIC)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryTraversingItemVisitor[] = {
	PHP_ME(RepositoryTraversingItemVisitor, __construct, php_ai_RepositoryTraversingItemVisitor___construct, ZEND_ACC_PUBLIC|ZEND_ACC_CTOR)
	PHP_ABSTRACT_ME(RepositoryTraversingItemVisitor, entering, php_ai_RepositoryTraversingItemVisitor_entering)
	PHP_ABSTRACT_ME(RepositoryTraversingItemVisitor, leaving, php_ai_RepositoryTraversingItemVisitor_leaving)
	PHP_ME(RepositoryTraversingItemVisitor, visit, php_ai_RepositoryTraversingItemVisitor_visit, ZEND_ACC_PUBLIC)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryValue[] = {
	PHP_ABSTRACT_ME(RepositoryValue, getString, php_ai_RepositoryValue_getString)
	PHP_ABSTRACT_ME(RepositoryValue, getStream, php_ai_RepositoryValue_getStream)
	PHP_ABSTRACT_ME(RepositoryValue, getLong, php_ai_RepositoryValue_getLong)
	PHP_ABSTRACT_ME(RepositoryValue, getDouble, php_ai_RepositoryValue_getDouble)
	PHP_ABSTRACT_ME(RepositoryValue, getDate, php_ai_RepositoryValue_getDate)
	PHP_ABSTRACT_ME(RepositoryValue, getBoolean, php_ai_RepositoryValue_getBoolean)
	PHP_ABSTRACT_ME(RepositoryValue, getType, php_ai_RepositoryValue_getType)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryValueFactory[] = {
	PHP_ABSTRACT_ME(RepositoryValueFactory, createValue, php_ai_RepositoryValueFactory_createValue)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryVersion[] = {
	PHP_ABSTRACT_ME(RepositoryVersion, getContainingHistory, php_ai_RepositoryVersion_getContainingHistory)
	PHP_ABSTRACT_ME(RepositoryVersion, getCreated, php_ai_RepositoryVersion_getCreated)
	PHP_ABSTRACT_ME(RepositoryVersion, getSuccessors, php_ai_RepositoryVersion_getSuccessors)
	PHP_ABSTRACT_ME(RepositoryVersion, getPredecessors, php_ai_RepositoryVersion_getPredecessors)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryVersionHistory[] = {
	PHP_ABSTRACT_ME(RepositoryVersionHistory, getVersionableUUID, php_ai_RepositoryVersionHistory_getVersionableUUID)
	PHP_ABSTRACT_ME(RepositoryVersionHistory, getRootVersion, php_ai_RepositoryVersionHistory_getRootVersion)
	PHP_ABSTRACT_ME(RepositoryVersionHistory, getAllVersions, php_ai_RepositoryVersionHistory_getAllVersions)
	PHP_ABSTRACT_ME(RepositoryVersionHistory, getVersion, php_ai_RepositoryVersionHistory_getVersion)
	PHP_ABSTRACT_ME(RepositoryVersionHistory, getVersionByLabel, php_ai_RepositoryVersionHistory_getVersionByLabel)
	PHP_ABSTRACT_ME(RepositoryVersionHistory, addVersionLabel, php_ai_RepositoryVersionHistory_addVersionLabel)
	PHP_ABSTRACT_ME(RepositoryVersionHistory, removeVersionLabel, php_ai_RepositoryVersionHistory_removeVersionLabel)
	PHP_ABSTRACT_ME(RepositoryVersionHistory, hasVersionLabel, php_ai_RepositoryVersionHistory_hasVersionLabel)
	PHP_ABSTRACT_ME(RepositoryVersionHistory, getVersionLabels, php_ai_RepositoryVersionHistory_getVersionLabels)
	PHP_ABSTRACT_ME(RepositoryVersionHistory, removeVersion, php_ai_RepositoryVersionHistory_removeVersion)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryVersionIterator[] = {
	PHP_ABSTRACT_ME(RepositoryVersionIterator, nextVersion, php_ai_RepositoryVersionIterator_nextVersion)
	{NULL,NULL,NULL,0}
};
zend_function_entry php_fe_RepositoryWorkspace[] = {
	PHP_ABSTRACT_ME(RepositoryWorkspace, getSession, php_ai_RepositoryWorkspace_getSession)
	PHP_ABSTRACT_ME(RepositoryWorkspace, getName, php_ai_RepositoryWorkspace_getName)
	PHP_ABSTRACT_ME(RepositoryWorkspace, copy, php_ai_RepositoryWorkspace_copy)
	PHP_ABSTRACT_ME(RepositoryWorkspace, clone_, php_ai_RepositoryWorkspace_clone_)
	PHP_ABSTRACT_ME(RepositoryWorkspace, move, php_ai_RepositoryWorkspace_move)
	PHP_ABSTRACT_ME(RepositoryWorkspace, restore, php_ai_RepositoryWorkspace_restore)
	PHP_ABSTRACT_ME(RepositoryWorkspace, getQueryManager, php_ai_RepositoryWorkspace_getQueryManager)
	PHP_ABSTRACT_ME(RepositoryWorkspace, getNamespaceRegistry, php_ai_RepositoryWorkspace_getNamespaceRegistry)
	PHP_ABSTRACT_ME(RepositoryWorkspace, getNodeTypeManager, php_ai_RepositoryWorkspace_getNodeTypeManager)
	PHP_ABSTRACT_ME(RepositoryWorkspace, getObservationManager, php_ai_RepositoryWorkspace_getObservationManager)
	PHP_ABSTRACT_ME(RepositoryWorkspace, getAccessibleWorkspaceNames, php_ai_RepositoryWorkspace_getAccessibleWorkspaceNames)
	PHP_ABSTRACT_ME(RepositoryWorkspace, getImportContentHandler, php_ai_RepositoryWorkspace_getImportContentHandler)
	PHP_ABSTRACT_ME(RepositoryWorkspace, importXML, php_ai_RepositoryWorkspace_importXML)
	{NULL,NULL,NULL,0}
};
/* }}} */

/* {{{ crapi_functions[] */
zend_function_entry crapi_functions[] = {
	{NULL, NULL, NULL}
};
/* }}} */

/* {{{ crapi_module_entry
 */
zend_module_entry crapi_module_entry = {
	STANDARD_MODULE_HEADER,
	"crapi",
	crapi_functions,
	PHP_MINIT(crapi),
	PHP_MSHUTDOWN(crapi),
	NULL,
	NULL,
	PHP_MINFO(crapi),
	PHP_CRAPI_VERSION,
	STANDARD_MODULE_PROPERTIES
};
/* }}} */

#ifdef COMPILE_DL_CRAPI
ZEND_GET_MODULE(crapi)
#endif

/* {{{ PHP_MINIT_FUNCTION */
PHP_MINIT_FUNCTION(crapi)
{
	zend_class_entry ce;
	
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "Repository", php_fe_Repository);
	php_ce_Repository = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "SPEC_VERSION_DESC", sizeof("SPEC_VERSION_DESC")-1, CRAPI_SPEC_VERSION_DESC TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "SPEC_NAME_DESC", sizeof("SPEC_NAME_DESC")-1, CRAPI_SPEC_NAME_DESC TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "REP_VENDOR_DESC", sizeof("REP_VENDOR_DESC")-1, CRAPI_REP_VENDOR_DESC TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "REP_VENDOR_URL_DESC", sizeof("REP_VENDOR_URL_DESC")-1, CRAPI_REP_VENDOR_URL_DESC TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "REP_NAME_DESC", sizeof("REP_NAME_DESC")-1, CRAPI_REP_NAME_DESC TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "REP_VERSION_DESC", sizeof("REP_VERSION_DESC")-1, CRAPI_REP_VERSION_DESC TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "LEVEL_1_SUPPORTED", sizeof("LEVEL_1_SUPPORTED")-1, CRAPI_LEVEL_1_SUPPORTED TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "LEVEL_2_SUPPORTED", sizeof("LEVEL_2_SUPPORTED")-1, CRAPI_LEVEL_2_SUPPORTED TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "OPTION_TRANSACTIONS_SUPPORTED", sizeof("OPTION_TRANSACTIONS_SUPPORTED")-1, CRAPI_OPTION_TRANSACTIONS_SUPPORTED TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "OPTION_VERSIONING_SUPPORTED", sizeof("OPTION_VERSIONING_SUPPORTED")-1, CRAPI_OPTION_VERSIONING_SUPPORTED TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "OPTION_OBSERVATION_SUPPORTED", sizeof("OPTION_OBSERVATION_SUPPORTED")-1, CRAPI_OPTION_OBSERVATION_SUPPORTED TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "OPTION_LOCKING_SUPPORTED", sizeof("OPTION_LOCKING_SUPPORTED")-1, CRAPI_OPTION_LOCKING_SUPPORTED TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "OPTION_QUERY_SQL_SUPPORTED", sizeof("OPTION_QUERY_SQL_SUPPORTED")-1, CRAPI_OPTION_QUERY_SQL_SUPPORTED TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "QUERY_XPATH_POS_INDEX", sizeof("QUERY_XPATH_POS_INDEX")-1, CRAPI_QUERY_XPATH_POS_INDEX TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "QUERY_XPATH_DOC_ORDER", sizeof("QUERY_XPATH_DOC_ORDER")-1, CRAPI_QUERY_XPATH_DOC_ORDER TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "QUERY_JCRPATH", sizeof("QUERY_JCRPATH")-1, CRAPI_QUERY_JCRPATH TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_Repository, "QUERY_JCRSCORE", sizeof("QUERY_JCRSCORE")-1, CRAPI_QUERY_JCRSCORE TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryRow", php_fe_RepositoryRow);
	php_ce_RepositoryRow = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryLock", php_fe_RepositoryLock);
	php_ce_RepositoryLock = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryValue", php_fe_RepositoryValue);
	php_ce_RepositoryValue = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryValueFactory", php_fe_RepositoryValueFactory);
	php_ce_RepositoryValueFactory = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryItem", php_fe_RepositoryItem);
	php_ce_RepositoryItem = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNode", php_fe_RepositoryNode);
	php_ce_RepositoryNode = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryNode TSRMLS_CC, 1, php_ce_RepositoryItem);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryProperty", php_fe_RepositoryProperty);
	php_ce_RepositoryProperty = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryProperty TSRMLS_CC, 1, php_ce_RepositoryItem);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryVersion", php_fe_RepositoryVersion);
	php_ce_RepositoryVersion = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryVersion TSRMLS_CC, 2, php_ce_RepositoryNode, php_ce_RepositoryItem);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryVersionHistory", php_fe_RepositoryVersionHistory);
	php_ce_RepositoryVersionHistory = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNodeType", php_fe_RepositoryNodeType);
	php_ce_RepositoryNodeType = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryEvent", php_fe_RepositoryEvent);
	php_ce_RepositoryEvent = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryEvent, "NODE_ADDED", sizeof("NODE_ADDED")-1, CRAPI_NODE_ADDED TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryEvent, "NODE_REMOVED", sizeof("NODE_REMOVED")-1, CRAPI_NODE_REMOVED TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryEvent, "PROPERTY_ADDED", sizeof("PROPERTY_ADDED")-1, CRAPI_PROPERTY_ADDED TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryEvent, "PROPERTY_REMOVED", sizeof("PROPERTY_REMOVED")-1, CRAPI_PROPERTY_REMOVED TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryEvent, "PROPERTY_CHANGED", sizeof("PROPERTY_CHANGED")-1, CRAPI_PROPERTY_CHANGED TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryQuery", php_fe_RepositoryQuery);
	php_ce_RepositoryQuery = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryQuery, "XPATH", sizeof("XPATH")-1, CRAPI_XPATH TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryQuery, "SQL", sizeof("SQL")-1, CRAPI_SQL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryQueryResult", php_fe_RepositoryQueryResult);
	php_ce_RepositoryQueryResult = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryQueryManager", php_fe_RepositoryQueryManager);
	php_ce_RepositoryQueryManager = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNodeTypeManager", php_fe_RepositoryNodeTypeManager);
	php_ce_RepositoryNodeTypeManager = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryObservationManager", php_fe_RepositoryObservationManager);
	php_ce_RepositoryObservationManager = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryEventListener", php_fe_RepositoryEventListener);
	php_ce_RepositoryEventListener = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNamespaceRegistry", php_fe_RepositoryNamespaceRegistry);
	php_ce_RepositoryNamespaceRegistry = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositorySession", php_fe_RepositorySession);
	php_ce_RepositorySession = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryCredentials", NULL);
	php_ce_RepositoryCredentials = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryWorkspace", php_fe_RepositoryWorkspace);
	php_ce_RepositoryWorkspace = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryWorkspace, "IMPORT_UUID_CREATE_NEW", sizeof("IMPORT_UUID_CREATE_NEW")-1, CRAPI_IMPORT_UUID_CREATE_NEW TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryWorkspace, "IMPORT_UUID_COLLISION_REMOVE_EXISTING", sizeof("IMPORT_UUID_COLLISION_REMOVE_EXISTING")-1, CRAPI_IMPORT_UUID_COLLISION_REMOVE_EXISTING TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryWorkspace, "IMPORT_UUID_COLLISION_REPLACE_EXISTING", sizeof("IMPORT_UUID_COLLISION_REPLACE_EXISTING")-1, CRAPI_IMPORT_UUID_COLLISION_REPLACE_EXISTING TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryWorkspace, "IMPORT_UUID_COLLISION_THROW", sizeof("IMPORT_UUID_COLLISION_THROW")-1, CRAPI_IMPORT_UUID_COLLISION_THROW TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryItemVisitor", php_fe_RepositoryItemVisitor);
	php_ce_RepositoryItemVisitor = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryItemDefinition", php_fe_RepositoryItemDefinition);
	php_ce_RepositoryItemDefinition = zend_register_internal_interface(&ce TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNodeDefinition", php_fe_RepositoryNodeDefinition);
	php_ce_RepositoryNodeDefinition = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryNodeDefinition TSRMLS_CC, 1, php_ce_RepositoryItemDefinition);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryPropertyDefinition", php_fe_RepositoryPropertyDefinition);
	php_ce_RepositoryPropertyDefinition = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryPropertyDefinition TSRMLS_CC, 1, php_ce_RepositoryItemDefinition);


	/* iterators */
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryRangeIterator", php_fe_RepositoryRangeIterator);
	php_ce_RepositoryRangeIterator = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryRangeIterator TSRMLS_CC, 1, zend_ce_iterator);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryRowIterator", php_fe_RepositoryRowIterator);
	php_ce_RepositoryRowIterator = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryRowIterator TSRMLS_CC, 2, php_ce_RepositoryRangeIterator, zend_ce_iterator);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNodeIterator", php_fe_RepositoryNodeIterator);
	php_ce_RepositoryNodeIterator = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryNodeIterator TSRMLS_CC, 2, php_ce_RepositoryRangeIterator, zend_ce_iterator);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryEventIterator", php_fe_RepositoryEventIterator);
	php_ce_RepositoryEventIterator = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryEventIterator TSRMLS_CC, 2, php_ce_RepositoryRangeIterator, zend_ce_iterator);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryVersionIterator", php_fe_RepositoryVersionIterator);
	php_ce_RepositoryVersionIterator = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryVersionIterator TSRMLS_CC, 2, php_ce_RepositoryRangeIterator, zend_ce_iterator);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryPropertyIterator", php_fe_RepositoryPropertyIterator);
	php_ce_RepositoryPropertyIterator = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryPropertyIterator TSRMLS_CC, 2, php_ce_RepositoryRangeIterator, zend_ce_iterator);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNodeTypeIterator", php_fe_RepositoryNodeTypeIterator);
	php_ce_RepositoryNodeTypeIterator = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryNodeTypeIterator TSRMLS_CC, 2, php_ce_RepositoryRangeIterator, zend_ce_iterator);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryEventListenerIterator", php_fe_RepositoryEventListenerIterator);
	php_ce_RepositoryEventListenerIterator = zend_register_internal_interface(&ce TSRMLS_CC);
	zend_class_implements(php_ce_RepositoryEventListenerIterator TSRMLS_CC, 2, php_ce_RepositoryRangeIterator, zend_ce_iterator);


	/* classes */
	INIT_CLASS_ENTRY(ce, "RepositorySimpleCredentials", php_fe_RepositorySimpleCredentials);
	php_ce_RepositorySimpleCredentials = zend_register_internal_class_ex(&ce, NULL, NULL TSRMLS_CC);
	php_ce_RepositorySimpleCredentials->ce_flags |= ZEND_ACC_FINAL;
	zend_class_implements(php_ce_RepositorySimpleCredentials TSRMLS_CC, 1, php_ce_RepositoryCredentials);
	zend_declare_property_null(php_ce_RepositorySimpleCredentials, "userId", sizeof("userId")-1, ZEND_ACC_PRIVATE TSRMLS_CC);
	zend_declare_property_null(php_ce_RepositorySimpleCredentials, "password", sizeof("password")-1, ZEND_ACC_PRIVATE TSRMLS_CC);
	zend_declare_property_null(php_ce_RepositorySimpleCredentials, "attributes", sizeof("attributes")-1, ZEND_ACC_PRIVATE TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryOnParentVersionAction", php_fe_RepositoryOnParentVersionAction);
	php_ce_RepositoryOnParentVersionAction = zend_register_internal_class_ex(&ce, NULL, NULL TSRMLS_CC);
	php_ce_RepositoryOnParentVersionAction->ce_flags |= ZEND_ACC_FINAL;
	zend_declare_class_constant_long(php_ce_RepositoryOnParentVersionAction, "COPY", sizeof("COPY")-1, CRAPI_COPY TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryOnParentVersionAction, "VERSION", sizeof("VERSION")-1, CRAPI_VERSION TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryOnParentVersionAction, "INITIALIZE", sizeof("INITIALIZE")-1, CRAPI_INITIALIZE TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryOnParentVersionAction, "COMPUTE", sizeof("COMPUTE")-1, CRAPI_COMPUTE TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryOnParentVersionAction, "IGNORE", sizeof("IGNORE")-1, CRAPI_IGNORE TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryOnParentVersionAction, "ABORT", sizeof("ABORT")-1, CRAPI_ABORT TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryOnParentVersionAction, "ACTIONNAME_COPY", sizeof("ACTIONNAME_COPY")-1, CRAPI_ACTIONNAME_COPY TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryOnParentVersionAction, "ACTIONNAME_VERSION", sizeof("ACTIONNAME_VERSION")-1, CRAPI_ACTIONNAME_VERSION TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryOnParentVersionAction, "ACTIONNAME_INITIALIZE", sizeof("ACTIONNAME_INITIALIZE")-1, CRAPI_ACTIONNAME_INITIALIZE TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryOnParentVersionAction, "ACTIONNAME_COMPUTE", sizeof("ACTIONNAME_COMPUTE")-1, CRAPI_ACTIONNAME_COMPUTE TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryOnParentVersionAction, "ACTIONNAME_IGNORE", sizeof("ACTIONNAME_IGNORE")-1, CRAPI_ACTIONNAME_IGNORE TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryOnParentVersionAction, "ACTIONNAME_ABORT", sizeof("ACTIONNAME_ABORT")-1, CRAPI_ACTIONNAME_ABORT TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryPropertyType", php_fe_RepositoryPropertyType);
	php_ce_RepositoryPropertyType = zend_register_internal_class_ex(&ce, NULL, NULL TSRMLS_CC);
	php_ce_RepositoryPropertyType->ce_flags |= ZEND_ACC_FINAL;
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "STRING", sizeof("STRING")-1, CRAPI_STRING TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "BINARY", sizeof("BINARY")-1, CRAPI_BINARY TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "LONG", sizeof("LONG")-1, CRAPI_LONG TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "DOUBLE", sizeof("DOUBLE")-1, CRAPI_DOUBLE TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "DATE", sizeof("DATE")-1, CRAPI_DATE TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "BOOLEAN", sizeof("BOOLEAN")-1, CRAPI_BOOLEAN TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "NAME", sizeof("NAME")-1, CRAPI_NAME TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "PATH", sizeof("PATH")-1, CRAPI_PATH TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "REFERENCE", sizeof("REFERENCE")-1, CRAPI_REFERENCE TSRMLS_CC);
	zend_declare_class_constant_long(php_ce_RepositoryPropertyType, "UNDEFINED", sizeof("UNDEFINED")-1, CRAPI_UNDEFINED TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_STRING", sizeof("TYPENAME_STRING")-1, CRAPI_TYPENAME_STRING TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_BINARY", sizeof("TYPENAME_BINARY")-1, CRAPI_TYPENAME_BINARY TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_LONG", sizeof("TYPENAME_LONG")-1, CRAPI_TYPENAME_LONG TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_DOUBLE", sizeof("TYPENAME_DOUBLE")-1, CRAPI_TYPENAME_DOUBLE TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_DATE", sizeof("TYPENAME_DATE")-1, CRAPI_TYPENAME_DATE TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_BOOLEAN", sizeof("TYPENAME_BOOLEAN")-1, CRAPI_TYPENAME_BOOLEAN TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_NAME", sizeof("TYPENAME_NAME")-1, CRAPI_TYPENAME_NAME TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_PATH", sizeof("TYPENAME_PATH")-1, CRAPI_TYPENAME_PATH TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_REFERENCE", sizeof("TYPENAME_REFERENCE")-1, CRAPI_TYPENAME_REFERENCE TSRMLS_CC);
	zend_declare_class_constant_string(php_ce_RepositoryPropertyType, "TYPENAME_UNDEFINED", sizeof("TYPENAME_UNDEFINED")-1, CRAPI_TYPENAME_UNDEFINED TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryTraversingItemVisitor", php_fe_RepositoryTraversingItemVisitor);
	php_ce_RepositoryTraversingItemVisitor = zend_register_internal_class_ex(&ce, NULL, NULL TSRMLS_CC);
	php_ce_RepositoryTraversingItemVisitor->ce_flags |= ZEND_ACC_ABSTRACT;
	zend_class_implements(php_ce_RepositoryTraversingItemVisitor TSRMLS_CC, 1, php_ce_RepositoryItemVisitor);
	zend_declare_property_null(php_ce_RepositoryTraversingItemVisitor, "breadthFirst", sizeof("breadthFirst")-1, ZEND_ACC_PROTECTED TSRMLS_CC);
	zend_declare_property_long(php_ce_RepositoryTraversingItemVisitor, "maxLevel", sizeof("maxLevel")-1, -1, ZEND_ACC_PROTECTED TSRMLS_CC);
	zend_declare_property_null(php_ce_RepositoryTraversingItemVisitor, "currentQueue", sizeof("currentQueue")-1, ZEND_ACC_PRIVATE TSRMLS_CC);
	zend_declare_property_null(php_ce_RepositoryTraversingItemVisitor, "nextQueue", sizeof("nextQueue")-1, ZEND_ACC_PRIVATE TSRMLS_CC);
	zend_declare_property_null(php_ce_RepositoryTraversingItemVisitor, "currentLevel", sizeof("currentLevel")-1, ZEND_ACC_PRIVATE TSRMLS_CC);


	/* exceptions */
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryException", NULL);
	php_ce_RepositoryException = zend_register_internal_class_ex(&ce, zend_exception_get_default(), NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryIOException", NULL);
	php_ce_RepositoryIOException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositorySAXException", NULL);
	php_ce_RepositorySAXException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryLockException", NULL);
	php_ce_RepositoryLockException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryLoginException", NULL);
	php_ce_RepositoryLoginException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryMergeException", NULL);
	php_ce_RepositoryMergeException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryVersionException", NULL);
	php_ce_RepositoryVersionException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNamespaceException", NULL);
	php_ce_RepositoryNamespaceException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryItemExistsException", NULL);
	php_ce_RepositoryItemExistsException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryValueFormatException", NULL);
	php_ce_RepositoryValueFormatException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryAccessDeniedException", NULL);
	php_ce_RepositoryAccessDeniedException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryPathNotFoundException", NULL);
	php_ce_RepositoryPathNotFoundException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryItemNotFoundException", NULL);
	php_ce_RepositoryItemNotFoundException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryInvalidQueryException", NULL);
	php_ce_RepositoryInvalidQueryException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryIllegalStateException", NULL);
	php_ce_RepositoryIllegalStateException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNumberFormatException", NULL);
	php_ce_RepositoryNumberFormatException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNoSuchElementException", NULL);
	php_ce_RepositoryNoSuchElementException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNoSuchNodeTypeException", NULL);
	php_ce_RepositoryNoSuchNodeTypeException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryIllegalArgumentException", NULL);
	php_ce_RepositoryIllegalArgumentException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryNoSuchWorkspaceException", NULL);
	php_ce_RepositoryNoSuchWorkspaceException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryInvalidItemStateException", NULL);
	php_ce_RepositoryInvalidItemStateException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryConstraintViolationException", NULL);
	php_ce_RepositoryConstraintViolationException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryReferentialIntegrityException", NULL);
	php_ce_RepositoryReferentialIntegrityException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryInvalidSerializedDataException", NULL);
	php_ce_RepositoryInvalidSerializedDataException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	memset(&ce, 0, sizeof(zend_class_entry));
	INIT_CLASS_ENTRY(ce, "RepositoryUnspportedOperationException", NULL);
	php_ce_RepositoryUnsupportedOperationException = zend_register_internal_class_ex(&ce, php_ce_RepositoryException, NULL TSRMLS_CC);
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MSHUTDOWN_FUNCTION */
PHP_MSHUTDOWN_FUNCTION(crapi)
{
	return SUCCESS;
}
/* }}} */

/* {{{ PHP_MINFO_FUNCTION */
PHP_MINFO_FUNCTION(crapi)
{
	php_info_print_table_start();
	php_info_print_table_header(2, "Content Repository API", "enabled");
	php_info_print_table_row(2, "Extension Version", PHP_CRAPI_VERSION);
	php_info_print_table_end();
}
/* }}} */

PHP_METHOD(RepositoryOnParentVersionAction, __construct)
{
}

PHP_METHOD(RepositoryOnParentVersionAction, nameFromValue)
{
	long v = 0;
	
	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &v)) {
		switch (v) {
			case CRAPI_COPY:
				RETURN_STRING(CRAPI_ACTIONNAME_COPY, 1);
			case CRAPI_VERSION:
				RETURN_STRING(CRAPI_ACTIONNAME_VERSION, 1);
			case CRAPI_INITIALIZE:
				RETURN_STRING(CRAPI_ACTIONNAME_INITIALIZE, 1);
			case CRAPI_COMPUTE:
				RETURN_STRING(CRAPI_ACTIONNAME_COMPUTE, 1);
			case CRAPI_IGNORE:
				RETURN_STRING(CRAPI_ACTIONNAME_IGNORE, 1);
			case CRAPI_ABORT:
				RETURN_STRING(CRAPI_ACTIONNAME_ABORT, 1);
		}
	}
	zend_throw_exception_ex(php_ce_RepositoryIllegalArgumentException TSRMLS_CC, 0, "Illegal Argument: %ld", v);
	RETURN_FALSE;
}

PHP_METHOD(RepositoryOnParentVersionAction, valueFromName)
{
	char *n = NULL;
	int l;
	
	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &n, &l)) {
		switch (n[0]) {
			case 'C':
			case 'c':
				if (!strcasecmp(n, CRAPI_ACTIONNAME_COPY)) {
					RETURN_LONG(CRAPI_COPY);
				}
				break;
			
			case 'V':
			case 'v':
				if (!strcasecmp(n, CRAPI_ACTIONNAME_VERSION)) {
					RETURN_LONG(CRAPI_VERSION);
				}
				break;
			
			case 'I':
			case 'i':
				if (!strcasecmp(n, CRAPI_ACTIONNAME_INITIALIZE)) {
					RETURN_LONG(CRAPI_INITIALIZE);
				}
				if (!strcasecmp(n, CRAPI_ACTIONNAME_IGNORE)) {
					RETURN_LONG(CRAPI_IGNORE);
				}
				break;
			
			case 'A':
			case 'a':
				if (!strcasecmp(n, CRAPI_ACTIONNAME_ABORT)) {
					RETURN_LONG(CRAPI_ABORT);
				}
				break;
		}
	}
	
	zend_throw_exception_ex(php_ce_RepositoryIllegalArgumentException TSRMLS_CC, 0, "Illegal Argument: %s", n);
	RETURN_FALSE;
}

PHP_METHOD(RepositoryPropertyType, nameFromValue)
{
	long v = 0;
	
	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &v)) {
		switch (v) {
			case CRAPI_STRING:
				RETURN_STRING(CRAPI_TYPENAME_STRING, 1);
			case CRAPI_BINARY:
				RETURN_STRING(CRAPI_TYPENAME_BINARY, 1);
			case CRAPI_BOOLEAN:
				RETURN_STRING(CRAPI_TYPENAME_BOOLEAN, 1);
			case CRAPI_LONG:
				RETURN_STRING(CRAPI_TYPENAME_LONG, 1);
			case CRAPI_DOUBLE:
				RETURN_STRING(CRAPI_TYPENAME_DOUBLE, 1);
			case CRAPI_DATE:
				RETURN_STRING(CRAPI_TYPENAME_DATE, 1);
			case CRAPI_PATH:
				RETURN_STRING(CRAPI_TYPENAME_PATH, 1);
			case CRAPI_NAME:
				RETURN_STRING(CRAPI_TYPENAME_NAME, 1);
			case CRAPI_REFERENCE:
				RETURN_STRING(CRAPI_TYPENAME_REFERENCE, 1);
		}
	}
	zend_throw_exception_ex(php_ce_RepositoryIllegalArgumentException TSRMLS_CC, 0, "Illegal Argument: %d", v);
	RETURN_FALSE;
}

PHP_METHOD(RepositoryPropertyType, valueFromName)
{
	char *n = NULL;
	int l;
	
	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &n, &l)) {
		switch (n[0]) {
			case 'B':
			case 'b':
				if (!strcasecmp(n, CRAPI_TYPENAME_BINARY)) {
					RETURN_LONG(CRAPI_BINARY);
				}
				if (!strcasecmp(n, CRAPI_TYPENAME_BOOLEAN)) {
					RETURN_LONG(CRAPI_BOOLEAN);
				}
				break;
				
			case 'S':
			case 's':
				if (!strcasecmp(n, CRAPI_TYPENAME_STRING)) {
					RETURN_LONG(CRAPI_STRING);
				}
				break;
				
			case 'L':
			case 'l':
				if (!strcasecmp(n, CRAPI_TYPENAME_LONG)) {
					RETURN_LONG(CRAPI_LONG);
				}
				break;
				
			case 'D':
			case 'd':
				if (!strcasecmp(n, CRAPI_TYPENAME_DOUBLE)) {
					RETURN_LONG(CRAPI_DOUBLE);
				}
				if (!strcasecmp(n, CRAPI_TYPENAME_DATE)) {
					RETURN_LONG(CRAPI_DATE);
				}
				break;
				
			case 'P':
			case 'p':
				if (!strcasecmp(n, CRAPI_TYPENAME_PATH)) {
					RETURN_LONG(CRAPI_PATH);
				}
				break;
				
			case 'N':
			case 'n':
				if (!strcasecmp(n, CRAPI_TYPENAME_NAME)) {
					RETURN_LONG(CRAPI_NAME);
				}
				break;
				
			case 'R':
			case 'r':
				if (!strcasecmp(n, CRAPI_TYPENAME_REFERENCE)) {
					RETURN_LONG(CRAPI_REFERENCE);
				}
				break;
		}
	}
	zend_throw_exception_ex(php_ce_RepositoryIllegalArgumentException TSRMLS_CC, 0, "Illegal Argument: %s", n);
	RETURN_FALSE;
}

PHP_METHOD(RepositorySimpleCredentials, __construct)
{
	zval *user, *pass;
	
	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "zz", &user, &pass)) {
		zend_update_property(Z_OBJCE_P(getThis()), getThis(), "userId", sizeof("userId")-1, user TSRMLS_CC);
		zend_update_property(Z_OBJCE_P(getThis()), getThis(), "password", sizeof("password")-1, pass TSRMLS_CC);
	} else {
		zend_throw_exception_ex(php_ce_RepositoryException TSRMLS_CC, 0, "Failed to initialize Credentials");
	}
}

PHP_METHOD(RepositorySimpleCredentials, getPassword)
{
	zval *pass = zend_read_property(Z_OBJCE_P(getThis()), getThis(), "password", sizeof("password")-1, 0 TSRMLS_CC);
	RETURN_ZVAL(pass, 1, 0);
}

PHP_METHOD(RepositorySimpleCredentials, getUserId)
{
	zval *user = zend_read_property(Z_OBJCE_P(getThis()), getThis(), "userId", sizeof("userId")-1, 0 TSRMLS_CC);
	RETURN_ZVAL(user, 1, 0);
}

PHP_METHOD(RepositorySimpleCredentials, setAttribute)
{
	char *n = NULL;
	int l;
	zval *v;
	
	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "sz", &n, &l, &v)) {
		if (l) {
			if (Z_TYPE_P(v) == IS_NULL) {
				zval *arg;
				
				MAKE_STD_ZVAL(arg);
				ZVAL_STRINGL(arg, n, l, 1);
				zend_call_method_with_1_params(&getThis(), Z_OBJCE_P(getThis()), NULL, "removeattribute", &return_value, arg);
				zval_ptr_dtor(&arg);
				return;
			} else {
				zval *attributes = zend_read_property(Z_OBJCE_P(getThis()), getThis(), "attributes", sizeof("attributes")-1, 0 TSRMLS_CC);
				
				if (Z_TYPE_P(attributes) == IS_ARRAY) {
					ZVAL_ADDREF(v);
					add_assoc_zval_ex(attributes, n, l+1, v);
				} else {
					MAKE_STD_ZVAL(attributes);
					array_init(attributes);
					ZVAL_ADDREF(v);
					add_assco_zval_ex(attributes, n, l+1, v);
					zend_update_property(Z_OBJCE_P(getThis()), getThis(), "attributes", sizeof("attributes")-1, attributes TSRMLS_CC);
				}
			}
		} else {
			zend_throw_exception_ex(php_ce_RepositoryIllegalArgumentException TSRMLS_CC, 0, "Attribute name cannot be empty");
		}
	} else {
		zend_throw_exception_ex(php_ce_RepositoryIllegalArgumentException TSRMLS_CC, 0, "Illegal Arguments");
	}
}

PHP_METHOD(RepositorySimpleCredentials, getAttribute)
{
	char *n = NULL;
	int l;
	
	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &n, &l)) {
		zval *attributes = zend_read_property(Z_OBJCE_P(getThis()), getThis(), "attributes", sizeof("attributes")-1, 0 TSRMLS_CC);
		
		if (Z_TYPE_P(attributes) == IS_ARRAY) {
			zval **a = NULL;
			
			if (SUCCESS == zend_hash_find(Z_ARRVAL_P(attributes), n, l+1, (void **) &a)) {
				RETURN_ZVAL(*a, 1, 0);
			}
		}
	}
}

PHP_METHOD(RepositorySimpleCredentials, removeAttribute)
{
	char *n;
	int l;
	
	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &n, &l)) {
		zval *attributes = zend_read_property(Z_OBJCE_P(getThis()), getThis(), "attributes", sizeof("attributes")-1, 0 TSRMLS_CC);
		
		if (Z_TYPE_P(attributes) == IS_ARRAY) {
			zend_hash_del(Z_ARRVAL_P(attributes), n, l+1);
		}
	}
}

PHP_METHOD(RepositorySimpleCredentials, getAttributeNames)
{
	HashPosition pos;
	char *key;
	uint len;
	ulong idx;
	zval *attributes = zend_read_property(Z_OBJCE_P(getThis()), getThis(), "attributes", sizeof("attributes")-1, 0 TSRMLS_CC);
	
	array_init(return_value);
	if (Z_TYPE_P(attributes) == IS_ARRAY) {
		for (	zend_hash_internal_pointer_reset_ex(Z_ARRVAL_P(attributes), &pos);
				HASH_KEY_NON_EXISTANT != zend_hash_get_current_key_ex(Z_ARRVAL_P(attributes), &key, &len, &idx, 1, &pos);
				zend_hash_move_forward_ex(Z_ARRVAL_P(attributes), &pos)) {
			add_next_index_stringl(return_value, key, len-1, 0);
		}
	}
}

PHP_METHOD(RepositoryTraversingItemVisitor, __construct)
{
	zend_bool breadth_first = 0;
	long max_level = -1;
	
	if (SUCCESS == zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "|bl", &breadth_first, &max_level)) {
		zval *array;
		
		zend_update_property_bool(Z_OBJCE_P(getThis()), getThis(), "breadthFirst", sizeof("breadthFirst")-1, breadth_first TSRMLS_CC);
		zend_update_property_long(Z_OBJCE_P(getThis()), getThis(), "maxLevel", sizeof("maxLevel")-1, max_level TSRMLS_CC);
		zend_update_property_long(Z_OBJCE_P(getThis()), getThis(), "currentLevel", sizeof("currentLevel")-1, 0 TSRMLS_CC);
		
		MAKE_STD_ZVAL(array);
		array_init(array);
		zend_update_property(Z_OBJCE_P(getThis()), getThis(), "currentQueue", sizeof("currentQueue")-1, array TSRMLS_CC);
		zval_ptr_dtor(&array);
		
		MAKE_STD_ZVAL(array);
		array_init(array);
		zend_update_property(Z_OBJCE_P(getThis()), getThis(), "nextQueue", sizeof("nexQueue")-1, array TSRMLS_CC);
		zval_ptr_dtor(&array);
	} else {
		zend_throw_exception_ex(php_ce_RepositoryIllegalArgumentException TSRMLS_CC, 0, "Illegal Arguments");
	}
}

PHP_METHOD(RepositoryTraversingItemVisitor, visit)
{/*
    public function visit( $entry ) {
        if ( $entry instanceof Property ) {
            $this->entering( $entry, $this->currentLevel );
            $this->leaving( $entry, $this->currentLevel );
        } else {
            try {
                if ( !$this->breadthFirst ) {
                    // depth-first traversal
                    $this->entering( $entry, $this->currentLevel );

                    if ( $this->maxLevel == -1 || $this->currentLevel < $this->maxLevel ) {
                        $this->currentLevel++;

                        $nodeIter = $entry->getNodes();

                        while ( $nodeIter->hasNext() ) {
                            $nodeIter->nextNode()->accept( $this );
                        }

                        $propIter = $entry->getProperties();

                        while ( $propIter->hasNext()) {
                            $propIter->nextProperty()->accept( $this );
                        }

                        $currentLevel--;
                    }

                    $this->leaving( $entry, $this->currentLevel );
                } else {
                    // breadth-first traversal
                    $this->entering( $entry, $this->currentLevel );
                    $this->leaving( $entry, $this->currentLevel );

                    if ( $this->maxLevel == -1 || $this->currentLevel < $this->maxLevel ) {
                        $nodeIter = $entry->getNodes();

                        while ( $nodeIter->hasNext() ) {
                            $this->nextQueue[] = $nodeIter->nextNode();
                        }

                        $propIter = $entry->getProperties();

                        while ( $propIter->hasNext() ) {
                            $this->nextQueue[] = $propIter->nextProperty();
                        }
                    }

                    while ( !empty( $this->currentQueue ) || !empty( $this->nextQueue ) ) {
                        if ( empty( $this->currentQueue ) ) {
                            $this->currentLevel++;
                            $this->currentQueue = $this->nextQueue;
                            $this->nextQueue = array();
                        }

                        $this->currentQueue = array_shift( $this->currentQueue );
                    }

                    $this->currentLevel = 0;
               }
            } catch ( RepositoryException $re ) {
                $this->currentLevel = 0;
                throw $re;
            }
        }
    }
*/
}

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
